summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcanvaspolygonalitem_imp.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qcanvaspolygonalitem_imp.cpp')
-rw-r--r--kjsembed/qtbindings/qcanvaspolygonalitem_imp.cpp90
1 files changed, 45 insertions, 45 deletions
diff --git a/kjsembed/qtbindings/qcanvaspolygonalitem_imp.cpp b/kjsembed/qtbindings/qcanvaspolygonalitem_imp.cpp
index 64500a9b..8dc06e3a 100644
--- a/kjsembed/qtbindings/qcanvaspolygonalitem_imp.cpp
+++ b/kjsembed/qtbindings/qcanvaspolygonalitem_imp.cpp
@@ -23,19 +23,19 @@
*/
namespace KJSEmbed {
-QCanvasPolygonalItemImp::QCanvasPolygonalItemImp( KJS::ExecState *exec, int mid, bool constructor )
+TTQCanvasPolygonalItemImp::TQCanvasPolygonalItemImp( KJS::ExecState *exec, int mid, bool constructor )
: JSProxyImp(exec), id(mid), cons(constructor)
{
}
-QCanvasPolygonalItemImp::~QCanvasPolygonalItemImp()
+TTQCanvasPolygonalItemImp::~TQCanvasPolygonalItemImp()
{
}
/**
* Adds bindings for static methods and enum constants to the specified Object.
*/
-void QCanvasPolygonalItemImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object )
+void TQCanvasPolygonalItemImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object )
{
JSProxy::MethodTable methods[] = {
@@ -43,11 +43,11 @@ void QCanvasPolygonalItemImp::addStaticBindings( KJS::ExecState *exec, KJS::Obje
};
int idx = 0;
- TQCString lastName;
+ TTQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
- QCanvasPolygonalItemImp *meth = new QCanvasPolygonalItemImp( exec, methods[idx].id );
+ TQCanvasPolygonalItemImp *meth = new TQCanvasPolygonalItemImp( exec, methods[idx].id );
object.put( exec , methods[idx].name, KJS::Object(meth) );
lastName = methods[idx].name;
}
@@ -60,7 +60,7 @@ void QCanvasPolygonalItemImp::addStaticBindings( KJS::ExecState *exec, KJS::Obje
/**
* Adds bindings for instance methods to the specified Object.
*/
-void QCanvasPolygonalItemImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
+void TQCanvasPolygonalItemImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
{
JSProxy::MethodTable methods[] = {
@@ -77,11 +77,11 @@ void QCanvasPolygonalItemImp::addBindings( KJS::ExecState *exec, KJS::Object &ob
};
int idx = 0;
- TQCString lastName;
+ TTQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
- QCanvasPolygonalItemImp *meth = new QCanvasPolygonalItemImp( exec, methods[idx].id );
+ TQCanvasPolygonalItemImp *meth = new TQCanvasPolygonalItemImp( exec, methods[idx].id );
object.put( exec , methods[idx].name, KJS::Object(meth) );
lastName = methods[idx].name;
}
@@ -90,61 +90,61 @@ void QCanvasPolygonalItemImp::addBindings( KJS::ExecState *exec, KJS::Object &ob
}
/**
* Extract a TQCanvasPolygonalItem pointer from an Object.
*/
-TQCanvasPolygonalItem *QCanvasPolygonalItemImp::toQCanvasPolygonalItem( KJS::Object &self )
+TTQCanvasPolygonalItem *TQCanvasPolygonalItemImp::toTQCanvasPolygonalItem( KJS::Object &self )
{
JSObjectProxy *ob = JSProxy::toObjectProxy( self.imp() );
if ( ob ) {
- TQObject *obj = ob->object();
+ TTQObject *obj = ob->object();
if ( obj )
- return dynamic_cast<TQCanvasPolygonalItem *>( obj );
+ return dynamic_cast<TTQCanvasPolygonalItem *>( obj );
}
JSOpaqueProxy *op = JSProxy::toOpaqueProxy( self.imp() );
if ( !op )
return 0;
- if ( op->typeName() != "TQCanvasPolygonalItem" )
+ if ( op->typeName() != "TTQCanvasPolygonalItem" )
return 0;
- return op->toNative<TQCanvasPolygonalItem>();
+ return op->toNative<TTQCanvasPolygonalItem>();
}
/**
* Select and invoke the correct constructor.
*/
-KJS::Object QCanvasPolygonalItemImp::construct( KJS::ExecState *exec, const KJS::List &args )
+KJS::Object TQCanvasPolygonalItemImp::construct( KJS::ExecState *exec, const KJS::List &args )
{
switch( id ) {
case Constructor_QCanvasPolygonalItem_1:
- return QCanvasPolygonalItem_1( exec, args );
+ return TQCanvasPolygonalItem_1( exec, args );
break;
default:
break;
}
- TQString msg = i18n("QCanvasPolygonalItemCons has no constructor with id '%1'.").arg(id);
+ TTQString msg = i18n("TQCanvasPolygonalItemCons has no constructor with id '%1'.").arg(id);
return throwError(exec, msg,KJS::ReferenceError);
}
-KJS::Object QCanvasPolygonalItemImp::QCanvasPolygonalItem_1( KJS::ExecState *exec, const KJS::List &args )
+KJS::Object TQCanvasPolygonalItemImp::TQCanvasPolygonalItem_1( KJS::ExecState *exec, const KJS::List &args )
{
#if 0 // This constructor has been disabled by the XSL template
// Unsupported parameter TQCanvas *
return KJS::Object();
- TQCanvas * arg0; // Dummy
+ TTQCanvas * arg0; // Dummy
- // We should now create an instance of the TQCanvasPolygonalItem object
+ // We should now create an instance of the TTQCanvasPolygonalItem object
- TQCanvasPolygonalItem *ret = new TQCanvasPolygonalItem(
+ TTQCanvasPolygonalItem *ret = new TTQCanvasPolygonalItem(
arg0 );
@@ -153,9 +153,9 @@ KJS::Object QCanvasPolygonalItemImp::QCanvasPolygonalItem_1( KJS::ExecState *exe
return KJS::Object();
}
-KJS::Value QCanvasPolygonalItemImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args )
+KJS::Value TQCanvasPolygonalItemImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args )
{
- instance = QCanvasPolygonalItemImp::toQCanvasPolygonalItem( self );
+ instance = TQCanvasPolygonalItemImp::toTQCanvasPolygonalItem( self );
switch( id ) {
@@ -199,18 +199,18 @@ KJS::Value QCanvasPolygonalItemImp::call( KJS::ExecState *exec, KJS::Object &sel
break;
}
- TQString msg = i18n( "QCanvasPolygonalItemImp has no method with id '%1'." ).arg( id );
+ TTQString msg = i18n( "TQCanvasPolygonalItemImp has no method with id '%1'." ).arg( id );
return throwError(exec, msg,KJS::ReferenceError);
}
-KJS::Value QCanvasPolygonalItemImp::collidesWith_3( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasPolygonalItemImp::collidesWith_3( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
// Unsupported parameter const TQCanvasItem *
return KJS::Value();
- const TQCanvasItem * arg0; // Dummy
+ const TTQCanvasItem * arg0; // Dummy
bool ret;
ret = instance->collidesWith(
@@ -219,13 +219,13 @@ KJS::Value QCanvasPolygonalItemImp::collidesWith_3( KJS::ExecState *exec, KJS::O
}
-KJS::Value QCanvasPolygonalItemImp::setPen_4( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasPolygonalItemImp::setPen_4( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- // Unsupported parameter QPen
+ // Unsupported parameter TQPen
return KJS::Value();
- TQPen arg0; // Dummy
+ TTQPen arg0; // Dummy
instance->setPen(
arg0 );
@@ -233,13 +233,13 @@ KJS::Value QCanvasPolygonalItemImp::setPen_4( KJS::ExecState *exec, KJS::Object
}
-KJS::Value QCanvasPolygonalItemImp::setBrush_5( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasPolygonalItemImp::setBrush_5( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- // Unsupported parameter QBrush
+ // Unsupported parameter TQBrush
return KJS::Value();
- TQBrush arg0; // Dummy
+ TTQBrush arg0; // Dummy
instance->setBrush(
arg0 );
@@ -247,50 +247,50 @@ KJS::Value QCanvasPolygonalItemImp::setBrush_5( KJS::ExecState *exec, KJS::Objec
}
-KJS::Value QCanvasPolygonalItemImp::pen_6( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasPolygonalItemImp::pen_6( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TQPen ret;
+ TTQPen ret;
ret = instance->pen( );
return convertToValue( exec, ret );
}
-KJS::Value QCanvasPolygonalItemImp::brush_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasPolygonalItemImp::brush_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TQBrush ret;
+ TTQBrush ret;
ret = instance->brush( );
return convertToValue( exec, ret );
}
-KJS::Value QCanvasPolygonalItemImp::areaPoints_8( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasPolygonalItemImp::areaPoints_8( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
instance->areaPoints( );
- return KJS::Value(); // Returns 'QPointArray'
+ return KJS::Value(); // Returns 'TQPointArray'
}
-KJS::Value QCanvasPolygonalItemImp::areaPointsAdvanced_9( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasPolygonalItemImp::areaPointsAdvanced_9( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
instance->areaPointsAdvanced( );
- return KJS::Value(); // Returns 'QPointArray'
+ return KJS::Value(); // Returns 'TQPointArray'
}
-KJS::Value QCanvasPolygonalItemImp::boundingRect_10( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasPolygonalItemImp::boundingRect_10( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TQRect ret;
+ TTQRect ret;
ret = instance->boundingRect( );
return convertToValue( exec, ret );
}
-KJS::Value QCanvasPolygonalItemImp::rtti_11( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasPolygonalItemImp::rtti_11( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int ret;
@@ -90,61 +90,61 @@ void QCanvasPolygonalItemImp::addBindings( KJS::ExecState *exec, KJS::Object &ob
}
/**
- * Extract a TQCanvasPolygonalItem pointer from an Object.
+ * Extract a TTQCanvasPolygonalItem pointer from an Object.
*/
@@ -90,61 +90,61 @@ void QCanvasPolygonalItemImp::addBindings( KJS::ExecState *exec, KJS::Object &ob
{
#if 0 // This constructor has been disabled by the XSL template
- // Unsupported parameter TQCanvas *
+ // Unsupported parameter TTQCanvas *
return KJS::Object();
@@ -199,18 +199,18 @@ KJS::Value QCanvasPolygonalItemImp::call( KJS::ExecState *exec, KJS::Object &sel
{
- // Unsupported parameter const TQCanvasItem *
+ // Unsupported parameter const TTQCanvasItem *
return KJS::Value();